@@ -171,7 +171,7 @@ swfdec_window_error (SwfdecWindow *window, const char *format, ...)
   va_list varargs;
 
   g_return_if_fail (SWFDEC_IS_WINDOW (window));
-  g_return_if_fail (msg != NULL);
+  g_return_if_fail (format != NULL);
 
   /* NB: This function can be called during the construction process (like when
    * the UI file isn't found, so a window object may not even exist. */
